function expn = MoveExpToYLab(yax)
% for a given yaxis of a plot, if there is an exponent (builtin matlab 
% scale factor shown at top of y axis, such as 10^3), remove it and 
% adjust the ylabel accordingly; output of this function is the exponent 
% value (3, in the case ot 10^3 builtin scale factor), with which
% you must then (separately from this function) scale all the data used 
% in the plot.
% 
% nota bene! the ylabel must have the character '[' in it; if this function
% modified the ylabel, it places the scale factor immediately after it.

yaxlim = yax.Limits;
expn = double(yax.Exponent);
yax.Limits = yaxlim/10^expn;
if expn ~= 0
    ylabel = yax.Label.String;
    parts = split(ylabel,'[');
    if length(parts) ~= 2
        fprintf('ERROR: MoveExpToYLab did not find [ in the ylabel.');
        pause;
    end
    yax.Label.String = sprintf('%s[10^{%d} %s',parts{1},expn,parts{2});
end



